---
editor_options: 
  markdown: 
    wrap: 72
---

# cccandies-demo-2025-input

This DataLad repository contains the ws3 input dataset that goes with the
SpaDES demo model defined in the
[cccandies-demo-202503](https://github.com/UBC-FRESH/cccandies-demo-202503)
(parent) GitHub repository. The parent (code) repository should include
a link to this child (data) repository, implemented as a git submodule.

## Notes on this dataset

This dataset was originally compiled for use as input for the ws3-based forest
estate modelling component of the SpaDES-based forest landscape carbon carrying
capacity simulation study presented in Boisvenue et al. (2022). This
dataset covers five timber supply areas---TSA 08, 16, 24, 40, 41---in
north-east corner of British Columbia (Canada). The dataset includes
vegetation resource inventory (VRI) data (adjusted to 2020 reference
year) stratified into analysis units (AU), merchantable timber volume
yield curves for unmanaged (first growth) and managed (second growth)
states, and TSA-wise harvest volume and area targets.

The process used to compile this dataset is documented in a series of Jupyter
notebooks published is published in
the [wbi_ria_yield](https://github.com/UBC-FRESH/wbi_ria_yield) GitHub
repository.

## References

Boisvenue, C., Paradis, G., Eddy, I. M., McIntire, E. J., & Chubaty, A.
M. (2022). Managing forest carbon and landscape capacities.
Environmental Research Letters, 17(11), 114013.
[link](https://iopscience.iop.org/article/10.1088/1748-9326/ac9919/pdf)
